function varargout = nic_rsdd_idenComp_view(varargin)
% NIC_RSDD_IDENCOMP_VIEW M-file for nic_rsdd_idenComp_view.fig
%      NIC_RSDD_IDENCOMP_VIEW, by itself, creates a new NIC_RSDD_IDENCOMP_VIEW or raises the existing
%      singleton*.
%
%      H = NIC_RSDD_IDENCOMP_VIEW returns the handle to a new NIC_RSDD_IDENCOMP_VIEW or the handle to
%      the existing singleton*.
%
%      NIC_RSDD_IDENCOMP_VIEW('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in NIC_RSDD_IDENCOMP_VIEW.M with the given input arguments.
%
%      NIC_RSDD_IDENCOMP_VIEW('Property','Value',...) creates a new NIC_RSDD_IDENCOMP_VIEW or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before nic_rsdd_idenComp_view_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to nic_rsdd_idenComp_view_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help nic_rsdd_idenComp_view

% Last Modified by GUIDE v2.5 29-Jun-2010 12:25:33

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @nic_rsdd_idenComp_view_OpeningFcn, ...
                   'gui_OutputFcn',  @nic_rsdd_idenComp_view_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before nic_rsdd_idenComp_view is made visible.
function nic_rsdd_idenComp_view_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to nic_rsdd_idenComp_view (see VARARGIN)

% Choose default command line output for nic_rsdd_idenComp_view
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes nic_rsdd_idenComp_view wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = nic_rsdd_idenComp_view_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on selection change in CompNOList.
function CompNOList_Callback(hObject, eventdata, handles)
% hObject    handle to CompNOList (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns CompNOList contents as cell array
%        contents{get(hObject,'Value')} returns selected item from CompNOList


% --- Executes during object creation, after setting all properties.
function CompNOList_CreateFcn(hObject, eventdata, handles)
% hObject    handle to CompNOList (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in ButtExtractOne.
function ButtExtractOne_Callback(hObject, eventdata, handles)
% hObject    handle to ButtExtractOne (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in ButtExtractAll.
function ButtExtractAll_Callback(hObject, eventdata, handles)
% hObject    handle to ButtExtractAll (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in ButtViewComp.
function ButtViewComp_Callback(hObject, eventdata, handles)
% hObject    handle to ButtViewComp (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in ButtCloseMe.
function ButtCloseMe_Callback(hObject, eventdata, handles)
% hObject    handle to ButtCloseMe (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


